@@ -96,7 +96,8 @@ class EcoNetApiInterface:
             return False
 
         self._mqtt_client = mqtt.Client(
-            self._get_client_id(),
+            callback_api_version=mqtt.CallbackAPIVersion.VERSION1,
+            client_id=self._get_client_id(),
             clean_session=True,
             userdata=None,
             protocol=mqtt.MQTTv311,
@@ -236,20 +237,22 @@ class EcoNetApiInterface:
     async def _authenticate(self, payload: dict) -> None:
 
         _session = ClientSession()
-        async with _session.post(
-            f"{REST_URL}/user/auth", json=payload, headers=HEADERS
-        ) as resp:
-            if resp.status == 200:
-                _json = await resp.json()
-                _LOGGER.debug(_json)
-                if _json.get("options")["success"]:
-                    self._user_token = _json.get("user_token")
-                    self._account_id = _json.get("options").get("account_id")
-                else:
-                    raise InvalidCredentialsError(_json.get("options")["message"])
-            else:
-                raise GenericHTTPError(resp.status)
-        await _session.close()
+        try:
+          async with _session.post(
+              f"{REST_URL}/user/auth", json=payload, headers=HEADERS
+          ) as resp:
+              if resp.status == 200:
+                  _json = await resp.json()
+                  _LOGGER.debug(_json)
+                  if _json.get("options")["success"]:
+                      self._user_token = _json.get("user_token")
+                      self._account_id = _json.get("options").get("account_id")
+                  else:
+                      raise InvalidCredentialsError(_json.get("options")["message"])
+              else:
+                  raise GenericHTTPError(resp.status)
+        finally:
+          await _session.close()
 
     def _on_connect(self, client, userdata, flags, rc):
         _LOGGER.debug(f"Connected with result code: {str(rc)}")
